@@ -196,6 +196,14 @@ void MainWindow::writeSettings()
     else {
         sett.setValue("icons", "0");
     }
+
+    QString Transitions;
+    if ( ui->transitions->checkState() == Qt::Checked ) {
+        themesett.setValue("transitions", "1");
+    }
+    else {
+        themesett.setValue("transitions", "0");
+    }
 }
 
 void MainWindow::readSettings()
@@ -203,6 +211,7 @@ void MainWindow::readSettings()
     QSettings sett("ThemeCustomizer", "Boxes");
     QSettings themesett("ThemeCustomizer", currenttheme);
     int icons = sett.value("icons").toInt();
+    int transitions = themesett.value("transitions").toInt();
     int snap = sett.value("snap").toInt();
     int fontsize = themesett.value("fontsize").toInt();
     QString fontsizestring = themesett.value("fontsize").toString();
@@ -225,6 +234,12 @@ void MainWindow::readSettings()
         ui->Icons->setCheckState(Qt::Unchecked);
     }
 
+    if ( transitions == 1 ) {
+        ui->transitions->setCheckState(Qt::Checked);
+    } else {
+        ui->transitions->setCheckState(Qt::Unchecked);
+    }
+
     if ( !fontsizestring.isEmpty() ) {
     ui->FontSize->setCurrentIndex(fontsize);
     }
@@ -325,6 +340,13 @@ void MainWindow::on_pushButton_clicked()
             Icons = "Don't show icon backgrounds";
         }
 
+        if ( ui->transitions->checkState() == Qt::Checked ) {
+            Transitions = "1";
+        }
+        else {
+            Transitions = "0";
+        }
+
         if ( ui->saveasnew->checkState() == Qt::Checked ) {
 
 
@@ -461,13 +483,18 @@ void MainWindow::runscript(QString command)
     muoks5->waitForFinished();
     progress.setValue(50);
 
-//       QMaemo5InformationBox::information(this, tr("Setting up snap-to-grid..."), 1);
-    progress.setLabelText(tr("Setting up snap-to-grid..."));
-//        sleep(2);
+    progress.setLabelText(tr("Setting up window transitions"));
+    systemcommand.clear();
+    systemcommand << "settransitions" << Transitions;
+    QProcess *muoks8 = new QProcess(this);
+    muoks8->start("/sbin/launchcustomizer", systemcommand);
+    muoks8->waitForFinished();
+
     progress.setValue(52);
     progress.setValue(54);
     progress.setValue(56);
     progress.setValue(58);
+    progress.setLabelText(tr("Setting up snap-to-grid..."));
     systemcommand.clear();
     systemcommand << "setsnaptogrid" << ui->Snap->text();
     QProcess *muoks6 = new QProcess(this);
@@ -475,13 +502,11 @@ void MainWindow::runscript(QString command)
     muoks6->waitForFinished();
     progress.setValue(60);
 
-//       QMaemo5InformationBox::information(this, tr("Setting up shortcut and bookmark sizes..."), 1);
-    progress.setLabelText(tr("Setting up shortcut and bookmark sizes..."));
-//        sleep(2);
     progress.setValue(62);
     progress.setValue(64);
     progress.setValue(66);
     progress.setValue(68);
+    progress.setLabelText(tr("Setting up shortcut and bookmark sizes..."));
     systemcommand.clear();
     systemcommand << "seticonsizes" << ui->lineEdit->text() << ui->lineEdit_2->text() << Icons;
     QProcess *muoks7 = new QProcess(this);
@@ -778,7 +803,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-49<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-50<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
