@@ -8,6 +8,14 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Use custom (fast) window transitions</source>
+        <translation>Käytä muokattuja (nopeita) ikkuna-animaatioita</translation>
+    </message>
+    <message>
+        <source>Setting up window transitions</source>
+        <translation>Asetetaan ikkuna-animaatioita</translation>
+    </message>
     <message>
         <source>Current theme: </source>
         <translation>Nykyinen teema: </translation>
